@@ -1,6 +1,7 @@
 
 
 from gitlabber import git
+from gitlabber.git import GitAction
 from unittest import mock
 from anytree import Node
 import pytest
@@ -21,7 +22,8 @@ def create_tree():
 @mock.patch('gitlabber.git.os')
 @mock.patch('gitlabber.git.git')
 @mock.patch('gitlabber.git.clone_or_pull_project')
-def test_create_new_user_dir(mock_clone_or_pull_project, mock_git, mock_os):
+@mock.patch('gitlabber.git.progress')
+def test_create_new_user_dir(mock_progress, mock_clone_or_pull_project, mock_git, mock_os):
     # git.git = mock.MagicMock()
     
     mock_os.path.exists.return_value = False
@@ -60,7 +62,7 @@ def test_pull_repo(mock_git):
     repo_instance = mock_git.Repo.return_value
     git.is_git_repo = mock.MagicMock(return_value=True)
 
-    git.clone_or_pull_project(None,"dummy_dir")
+    git.clone_or_pull_project(GitAction(Node(name="test"), "dummy_dir"))
     mock_git.Repo.assert_called_once_with("dummy_dir")
     repo_instance.remotes.origin.pull.assert_called_once()
 
@@ -72,7 +74,7 @@ def test_clone_repo(mock_git):
     git.is_git_repo = mock.MagicMock(return_value=False)
 
     git.clone_or_pull_project(
-        Node(name="dummy_url", url="dummy_url"), "dummy_dir")
+        GitAction(Node(name="dummy_url", url="dummy_url"), "dummy_dir"))
 
     mock_git.Repo.clone_from.assert_called_once_with("dummy_url", "dummy_dir")
 
@@ -86,8 +88,8 @@ def test_pull_repo_interrupt(mock_git):
     repo_instance.remotes.origin.pull.side_effect=KeyboardInterrupt('pull test keyboard interrupt')
 
     with pytest.raises(SystemExit):
-        git.clone_or_pull_project(
-            Node(name="dummy_url", url="dummy_url"), "dummy_dir")
+        git.clone_or_pull_project(GitAction(
+            Node(name="dummy_url", url="dummy_url"), "dummy_dir"))
 
     mock_git.Repo.assert_called_once_with("dummy_dir")
     repo_instance.remotes.origin.pull.assert_called_once()
@@ -100,7 +102,7 @@ def test_clone_repo_interrupt(mock_git):
     mock_git.Repo.clone_from.side_effect=KeyboardInterrupt('clone test keyboard interrupt')
 
     with pytest.raises(SystemExit):
-        git.clone_or_pull_project(
-            Node(name="dummy_url", url="dummy_url"), "dummy_dir")
+        git.clone_or_pull_project(GitAction(
+            Node(name="dummy_url", url="dummy_url"), "dummy_dir"))
 
-    mock_git.Repo.clone_from.assert_called_once_with("dummy_url", "dummy_dir")
\ No newline at end of file
+    mock_git.Repo.clone_from.assert_called_once_with("dummy_url", "dummy_dir")
