@@ -27,11 +27,11 @@ def test_help():
     assert "Gitlabber - clones or pulls entire groups/projects tree from gitlab" in output
 
 
-def test_help():
+def test_version():
     output = execute(["--version"])
     assert VERSION in output
 
 def test_file_input():
-    output = execute(["-f", gitlab_util.YAML_TEST_INPUT_FILE, "-p"])
+    output = execute(["-f", gitlab_util.YAML_TEST_INPUT_FILE, "-p", '-t', 'xxx'])
     with open(gitlab_util.TREE_TEST_OUTPUT_FILE, 'r') as treeFile:
         assert treeFile.read().strip() == output.strip()
\ No newline at end of file
